# Sources
- `Calc_3d.py`
- `Calc_diff_ops.py`
- `Taylor.py`
- `Get_Diff_Op_mat_vec.py`

# Required pacakges
- numpy: `conda intall numpy`
- scipy: `conda install scipy`
- icecream: `conda install icecream` (conda-forge channel)
- progress: `conda install progress`
- cm2utils: `[your anaconda env]/bin/pip install cm2utils`, developed by CM2Lab.

# Last update
- April 26, 2021